@@ -92,6 +92,15 @@ class MailgunTrackingWebhookView(MailgunBaseWebhookView):
             mta_status = int(esp_event['code'])
         except (KeyError, TypeError):
             pass
+        except ValueError:
+            # RFC-3463 extended SMTP status code (class.subject.detail, where class is "2", "4" or "5")
+            try:
+                status_class = esp_event['code'].split('.')[0]
+            except (TypeError, IndexError):
+                # illegal SMTP status code format
+                pass
+            else:
+                reject_reason = RejectReason.BOUNCED if status_class in ("4", "5") else RejectReason.OTHER
         else:
             reject_reason = self.reject_reasons.get(
                 mta_status,
@@ -104,7 +113,7 @@ class MailgunTrackingWebhookView(MailgunBaseWebhookView):
         try:
             headers = json.loads(esp_event['message-headers'])
         except (KeyError, ):
-            metadata = None
+            metadata = {}
         else:
             variables = [value for [field, value] in headers
                          if field == 'X-Mailgun-Variables']
@@ -112,10 +121,10 @@ class MailgunTrackingWebhookView(MailgunBaseWebhookView):
                 # Each X-Mailgun-Variables value is JSON. Parse and merge them all into single dict:
                 metadata = combine(*[json.loads(value) for value in variables])
             else:
-                metadata = None
+                metadata = {}
 
         # tags are sometimes delivered as X-Mailgun-Tag fields, sometimes as tag
-        tags = esp_event.getlist('tag', esp_event.getlist('X-Mailgun-Tag', None))
+        tags = esp_event.getlist('tag', esp_event.getlist('X-Mailgun-Tag', []))
 
         return AnymailTrackingEvent(
             event_type=event_type,
