@@ -81,7 +81,7 @@ class MandrillTrackingWebhookView(MandrillBaseWebhookView):
         'send': EventType.SENT,
         'deferral': EventType.DEFERRED,
         'hard_bounce': EventType.BOUNCED,
-        'soft_bounce': EventType.DEFERRED,
+        'soft_bounce': EventType.BOUNCED,
         'open': EventType.OPENED,
         'click': EventType.CLICKED,
         'spam': EventType.COMPLAINED,
@@ -128,12 +128,12 @@ class MandrillTrackingWebhookView(MandrillBaseWebhookView):
         try:
             metadata = esp_event['msg']['metadata']
         except KeyError:
-            metadata = None
+            metadata = {}
 
         try:
             tags = esp_event['msg']['tags']
         except KeyError:
-            tags = None
+            tags = []
 
         return AnymailTrackingEvent(
             click_url=esp_event.get('url', None),
